@@ -1,4 +1,5 @@
 import matplotlib.pyplot as _plt
+from collections import deque
 import inspect as _inspect
 from typing import Sequence as _Sequence
 
@@ -6,18 +7,21 @@ from typing import Sequence as _Sequence
 class __DirectPlot:
     """Internal class used for the internal singleton object __dp"""
 
-    def __init__(self, titles: _Sequence[str], linesPerSubplot: int = 4, showMarker: bool = True) -> None:
-        self._create(titles, linesPerSubplot, showMarker)
+    def __init__(self, titles: _Sequence[str], linesPerSubplot: int = 4, showMarker: bool = True, maxPoints: int = 10000) -> None:
+        self._create(titles, linesPerSubplot, showMarker, maxPoints)
 
-    # Besser keinen Destructor. Der löst bei Programm-Ende durch Exceptions weitere Exceptions aus...
+    # At this time, it is better not to have a destructor.
+    # Reason: The implementation below seems to cause additional exceptions
+    #         in case the program is ended due an exception.
     # def __del__(self) -> None:
     #     self.close()
 
-    def _create(self, titles: _Sequence[str], linesPerSubplot: int = 4, showMarker: bool = True) -> None:
+    def _create(self, titles: _Sequence[str], linesPerSubplot: int = 4, showMarker: bool = True, maxPoints: int = 10000) -> None:
         if isinstance(titles, str):
             titles = (titles, )
         
         self.titles = titles
+        self.maxPoints = maxPoints
         self.linesPerSubplot = linesPerSubplot
 
         self.subPlotCount = len(titles)
@@ -27,12 +31,12 @@ class __DirectPlot:
         if not (_plt.isinteractive()): 
             _plt.ion()
 
-        self.xLists=[[]]
-        self.yLists=[[]]
+        self.xDeques=[]
+        self.yDeques=[]
         self.lines2d=[]
 
         self.fig, self.axs = _plt.subplots(1, self.subPlotCount, figsize=(4*self.subPlotCount, 3.5))
-        # self.axs soll auch bei nur einem Plot ein Interable sein:
+        # Ensure self.axs is an iterable, even in case of just one sub-plot:
         if self.subPlotCount==1: self.axs = (self.axs, )
 
         for i, title in enumerate(titles):
@@ -41,11 +45,11 @@ class __DirectPlot:
             self.axs[i].set_ylabel("ylabel")
 
             for plot_idx in range(linesPerSubplot):
-                newXlist = []
-                self.xLists.append(newXlist)
-                newYlist = []
-                self.yLists.append(newYlist)
-                line2d, = self.axs[i].plot(newXlist, newYlist, label=f"id {i*linesPerSubplot+plot_idx}", marker="." if showMarker else "") # marker='o',
+                newXdeque = deque(maxlen=self.maxPoints)
+                self.xDeques.append(newXdeque)
+                newYdeque = deque(maxlen=self.maxPoints)
+                self.yDeques.append(newYdeque)
+                line2d, = self.axs[i].plot(newXdeque, newYdeque, label=f"id {i*linesPerSubplot+plot_idx}", marker="." if showMarker else "") # marker='o',
                 self.lines2d.append(line2d)
 
             self.axs[i].legend(loc='upper right')
@@ -58,8 +62,8 @@ class __DirectPlot:
     def close(self) -> None:
         try:
             _plt.close(self.fig)
-            del(self.xLists)
-            del(self.yLists)
+            del(self.xDeques)
+            del(self.yDeques)
             del(self.lines2d)
             del(self.fig)
             del(self.axs)
@@ -71,8 +75,8 @@ class __DirectPlot:
         _plt.pause(0.001)
         _plt.ioff()
         _plt.show()
-        del(self.xLists)
-        del(self.yLists)
+        del(self.xDeques)
+        del(self.yDeques)
         del(self.lines2d)
         del(self.fig)
         del(self.axs)
@@ -85,9 +89,9 @@ class __DirectPlot:
         if id<0 or id>=self.subPlotCount*self.linesPerSubplot:
             raise ValueError(f"ERROR in directplot.{_inspect.currentframe().f_code.co_name}(): YOUR id VALUE {id} IS OUT OF THE ALLOWED RANGE OF [0...{len(self.lines2d)-1}]!")
 
-        self.xLists[id].append(x)
-        self.yLists[id].append(y)
-        self.lines2d[id].set_data(self.xLists[id], self.yLists[id])
+        self.xDeques[id].append(x)
+        self.yDeques[id].append(y)
+        self.lines2d[id].set_data(self.xDeques[id], self.yDeques[id])
         if refresh:
             ax_idx = id // self.linesPerSubplot
             self.axs[ax_idx].relim()
